@@ -12,7 +12,7 @@
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-defs.h>
 #include "gnome-cal.h"
-
+#include "modify-cats.h"
 
 BEGIN_GNOME_DECLS
 
@@ -34,6 +34,9 @@ struct _GncalTodo {
 
 	GtkWidget *edit_button;
 	GtkWidget *delete_button;
+	GSList *data_ptrs;
+  
+ 
 };
 
 struct _GncalTodoClass {
