@@ -113,20 +113,22 @@ gnome_calendar_goto (GnomeCalendar *gcal, time_t new_time)
 	current = get_current_page (gcal);
 	new_time = time_day_begin (new_time);
 
-	if (current == gcal->day_view)
+	if (current == gcal->day_view) {
 		gncal_day_panel_set (GNCAL_DAY_PANEL (gcal->day_view), new_time);
-	else if (current == gcal->week_view)
+		gcal->current_day_display = new_time;
+	} else if (current == gcal->week_view) {
 		gncal_week_view_set (GNCAL_WEEK_VIEW (gcal->week_view), new_time);
-	else if (current == gcal->month_view)
+		gcal->current_week_display = new_time;
+	} else if (current == gcal->month_view) {
 		month_view_set (MONTH_VIEW (gcal->month_view), new_time);
-	else if (current == gcal->year_view_sw)
+		gcal->current_month_display = new_time;
+	} else if (current == gcal->year_view_sw) {
 		year_view_set (YEAR_VIEW (gcal->year_view), new_time);
-	else {
+		gcal->current_year_display = new_time;
+	} else {
 		g_warning ("My penguin is gone!");
 		g_assert_not_reached ();
 	}
-
-	gcal->current_display = new_time;
 }
 
 static void
@@ -136,13 +138,13 @@ gnome_calendar_direction (GnomeCalendar *gcal, int direction)
 	time_t new_time;
 
 	if (cp == gcal->day_view)
-		new_time = time_add_day (time_day_begin (gcal->current_display), 1 * direction);
+		new_time = time_add_day (time_day_begin (gcal->current_day_display), 1 * direction);
 	else if (cp == gcal->week_view)
-		new_time = time_add_week (time_week_begin (gcal->current_display), 1 * direction);
+		new_time = time_add_week (time_week_begin (gcal->current_week_display), 1 * direction);
 	else if (cp == gcal->month_view)
-		new_time = time_add_month (time_month_begin (gcal->current_display), 1 * direction);
+		new_time = time_add_month (time_month_begin (gcal->current_month_display), 1 * direction);
 	else if (cp == gcal->year_view_sw)
-		new_time = time_add_year (time_year_begin (gcal->current_display), 1 * direction);
+		new_time = time_add_year (time_year_begin (gcal->current_year_display), 1 * direction);
 	else {
 		g_warning ("Weee!  Where did the penguin go?");
 		g_assert_not_reached ();
@@ -226,7 +228,8 @@ gnome_calendar_new (char *title)
 
 	gtk_window_set_title(GTK_WINDOW(retval), title);
 
-	gcal->current_display = time_day_begin (time (NULL));
+	gcal->current_day_display = gcal->current_week_display = gcal->current_month_display = 
+		gcal->current_year_display =time_day_begin (time (NULL));
 	gcal->cal = calendar_new (title,CALENDAR_INIT_ALARMS);
 	setup_widgets (gcal);
 	gnome_calendar_create_corba_server (gcal);
@@ -418,14 +421,54 @@ timeout_beep (gpointer data)
 	return FALSE;
 }
 
+static void
+alarm_dialog_clicked (GnomeDialog* dialog, int button, gpointer data)
+{
+	time_t now, diff;
+	CalendarAlarm *which = gtk_object_get_data (GTK_OBJECT (dialog),
+						    "cal_alarm");
+	iCalObject *ico = (iCalObject*) data;
+	
+	gboolean is_audio = (&ico->aalarm == which);
+
+	switch (button) {
+	case 1:
+		if (is_audio)
+			stop_beeping (GTK_OBJECT (dialog), NULL);
+		now = time (NULL);
+		diff = now - which->trigger;
+		which->trigger = which->trigger + diff + snooze_secs;
+		which->offset  = which->offset - diff - snooze_secs;
+		alarm_add (which, &calendar_notify, data);
+		break;
+	default:
+		if (is_audio)
+			stop_beeping (GTK_OBJECT (dialog), NULL);
+		break;
+	}
+}
+
+static gboolean
+alarm_dialog_closed (GnomeDialog* dialog, gpointer data)
+{
+	CalendarAlarm *which = gtk_object_get_data (GTK_OBJECT (dialog),
+						    "cal_alarm");
+	iCalObject *ico = (iCalObject*) data;
+	
+	gboolean is_audio = (&ico->aalarm == which);
+
+	if (is_audio)
+		stop_beeping (GTK_OBJECT (dialog), NULL);
+	
+	return FALSE;
+}
+
 void
 calendar_notify (time_t activation_time, CalendarAlarm *which, void *data)
 {
 	iCalObject *ico = data;
 	guint beep_tag, timer_tag;
-	int ret;
 	gchar* snooze_button = (enable_snooze ? _("Snooze") : NULL);
-	time_t now, diff;
 
 	if (&ico->aalarm == which){
 		time_t app = ico->aalarm.trigger + ico->aalarm.offset;
@@ -448,23 +491,14 @@ calendar_notify (time_t activation_time, CalendarAlarm *which, void *data)
 				     GINT_TO_POINTER (timer_tag));
 		gtk_object_set_data (GTK_OBJECT (w), "beep_tag",
 				     GINT_TO_POINTER (beep_tag));
-		gtk_widget_ref (w);
-		ret = gnome_dialog_run (GNOME_DIALOG (w));
-		switch (ret) {
-		case 1:
-			stop_beeping (GTK_OBJECT (w), NULL);
-			now = time (NULL);
-			diff = now - which->trigger;
-			which->trigger = which->trigger + diff + snooze_secs;
-			which->offset  = which->offset - diff - snooze_secs;
-			alarm_add (which, &calendar_notify, data);
-			break;
-		default:
-			stop_beeping (GTK_OBJECT (w), NULL);
-			break;
-		}
-		
-		gtk_widget_unref (w);
+		gtk_object_set_data (GTK_OBJECT (w), "cal_alarm", which);
+		gtk_signal_connect (GTK_OBJECT (w), "clicked",
+				    GTK_SIGNAL_FUNC (alarm_dialog_clicked),
+				    data);
+		gtk_signal_connect (GTK_OBJECT (w), "close",
+				    GTK_SIGNAL_FUNC (alarm_dialog_closed),
+				    data);
+		gtk_widget_show (w);
 		return;
 	}
 
@@ -492,19 +526,11 @@ calendar_notify (time_t activation_time, CalendarAlarm *which, void *data)
 					ico->summary, "'", NULL);
 		w = gnome_message_box_new (msg, GNOME_MESSAGE_BOX_INFO, 
 					   _("Ok"), snooze_button, NULL);
-		ret = gnome_dialog_run (GNOME_DIALOG (w));
-		switch (ret) {
-		case 1:
-			now = time (NULL);
-			diff = now - which->trigger;
-			which->trigger = which->trigger + diff + snooze_secs;
-			which->offset  = which->offset - diff - snooze_secs;
-			alarm_add (which, &calendar_notify, data);
-			break;
-		default:
-			break;
-		}
-		
+		gtk_object_set_data (GTK_OBJECT (w), "cal_alarm", which);
+		gtk_signal_connect (GTK_OBJECT (w), "clicked",
+				    GTK_SIGNAL_FUNC (alarm_dialog_clicked),
+				    data);
+		gtk_widget_show (w);
 		return;
 	}
 }
@@ -610,4 +636,20 @@ gnome_calendar_todo_properties_changed (GnomeCalendar *gcal)
 	todo_list_properties_changed (GNCAL_DAY_PANEL (gcal->day_view));
 }
 
-
+time_t
+gnome_calendar_current_display (GnomeCalendar *gcal)
+{
+	GtkWidget *page;
+	page = get_current_page (gcal);
+	if (page == gcal->day_view)
+		return gcal->current_day_display;
+	if (page == gcal->week_view)
+		return gcal->current_week_display;
+	if (page == gcal->month_view)
+		return gcal->current_month_display;
+	if (page == gcal->year_view_sw)
+		return gcal->current_year_display;
+	g_assert_not_reached();
+	return -1;
+}
+	
