@@ -54,7 +54,15 @@ enum PropertyType
 	PROP_VERSION = 27,
 	PROP_KEY = 28,
 	PROP_CATEGORIES = 29,
-	PROP_LAST = 30 /* Must always be the last, with the gratest value. */
+	PROP_XTENSION_LIST = 30,
+	PROP_VALUE = 31,
+	PROP_ENCODING = 32,
+	PROP_QUOTED_PRINTABLE = 33,
+	PROP_8BIT = 34,
+	PROP_BASE64 = 35,
+	PROP_LANG = 36,
+	PROP_CHARSET = 37,
+	PROP_LAST = 38 /* Must always be the last, with the gratest value. */
 };
 
 enum EncodType
